==> simpleSession-2.1.1-sources.jar: com/sinosoftgz/simpleSession/data/redis/RedisSessionCache.java <==
package com.sinosoftgz.simpleSession.data.redis;

import com.sinosoftgz.simpleSession.data.SessionMap;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.sinosoftgz.simpleSession.data.SerializeUtil;
import com.sinosoftgz.simpleSession.data.SessionCache;
import redis.clients.jedis.Jedis;

public class RedisSessionCache implements SessionCache{
	
	private static final Logger LOG =LoggerFactory.getLogger(RedisSessionCache.class);
	
	private redis.clients.jedis.JedisPool cachePool;
	
	@Override
	public boolean put(String sessionId, SessionMap sessionMap, int timeout) {
		boolean flag = false;
		Jedis jedis = null;
		jedis = cachePool.getResource();
		if (jedis == null) {
			return false;
		}
		try {
            jedis.set(sessionId.getBytes(), SerializeUtil.serialize(sessionMap));
            jedis.expire(sessionId, timeout);
            flag = true;
		} catch (Exception e) {
			LOG.error("Put session to redis error", e);
			return false;
		} finally {
			jedis.close();
		}
		return flag;
	}

	@Override
	public SessionMap get(String sessionId) {
		Jedis jedis = null;
		SessionMap sessionMap = null;
		byte[] reslut = null;
		jedis = cachePool.getResource();
		if (jedis == null) {
			return null;
		}
        try {
            if (jedis.exists(sessionId)) {
                reslut = jedis.get(sessionId.getBytes());
                sessionMap = (SessionMap) SerializeUtil.unserialize(reslut);
            }
        } catch (Exception e) {
        	LOG.error("Read session from redis error", e);
            return null;
        } finally {
        	jedis.close();
        }
        return sessionMap;
	}

	@Override
	public void setMaxInactiveInterval(String sessionId, int interval) {
		Jedis jedis = null;
		jedis = cachePool.getResource();
		if (null == jedis) {
			LOG.error("jedis is null...");;
			return;
		}
        try {
            
            if (jedis.exists(sessionId)) {
            	jedis.expire(sessionId, interval);
            }
        } catch (Exception e) {
        	LOG.error("Set session max inactive interval to redis error", e);
        } finally {
        	jedis.close();
        }
	}

	@Override
	public void destroy(String sessionId) {
		Jedis jedis = null;
		jedis = cachePool.getResource();
		if (null == jedis) {
			LOG.error("jedis is null...");;
			return;
		}
        try {
            if (jedis.exists(sessionId)) {
            	jedis.expire(sessionId, 0);
            }
        } catch (Exception e) {
        	LOG.error("Destroy session from redis error", e);
        } finally {
        	jedis.close();
        }

	}

	public void setCachePool(redis.clients.jedis.JedisPool cachePool) {
		this.cachePool = cachePool;
	}

	@Override
	public boolean isJedisActive(){
		Jedis jedis= null;
		try {
			 jedis = cachePool.getResource();
			if (null == jedis) {
				LOG.error("jedis is canot connected...");
				return false;
			}
		}catch (Exception e){
			LOG.error("jedis is canot connected...");
			return false;
		}finally {
			if (jedis!=null){
				try {
					jedis.close();
				}catch (Exception e){
					return false;
				}
			}
		}
		
		return true;
	}

	

}

==> simpleSession-2.2.0-sources.jar: com/sinosoftgz/simpleSession/data/redis/RedisSessionCache.java <==
package com.sinosoftgz.simpleSession.data.redis;

import com.sinosoftgz.simpleSession.data.SessionMap;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.sinosoftgz.simpleSession.data.SerializeUtil;
import com.sinosoftgz.simpleSession.data.SessionCache;
import redis.clients.jedis.Jedis;

public class RedisSessionCache implements SessionCache{
	
	private static final Logger LOG =LoggerFactory.getLogger(RedisSessionCache.class);
	
	private redis.clients.jedis.JedisCluster JedisCluster;
	
	@Override
	public boolean put(String sessionId, SessionMap sessionMap, int timeout) {
		boolean flag = false;
		Jedis jedis = null;
		//jedis = JedisCluster.getResource();
		if (jedis == null) {
			return false;
		}
		try {
			JedisCluster.set(sessionId , SerializeUtil.serializeToString(sessionMap));
            jedis.expire(sessionId, timeout);
            flag = true;
		} catch (Exception e) {
			LOG.error("Put session to redis error", e);
			return false;
		} finally {
			jedis.close();
		}
		return flag;
	}

	@Override
	public SessionMap get(String sessionId) {
		SessionMap sessionMap = null;
		String reslut = null;
        try {
            if (JedisCluster.exists(sessionId)) {
                reslut = JedisCluster.get(sessionId);
                sessionMap = (SessionMap) SerializeUtil.unserializeFromString(reslut);
            }
        } catch (Exception e) {
			LOG.error("Read session from redis error", e);
            return null;
        }
        return sessionMap;
	}

	@Override
	public void setMaxInactiveInterval(String sessionId, int interval) {
        try {
            if (JedisCluster.exists(sessionId)) {
				JedisCluster.expire(sessionId, interval);
            }
        } catch (Exception e) {
        	LOG.error("Set session max inactive interval to redis error", e);
        }
	}

	@Override
	public void destroy(String sessionId) {
        try {
            if (JedisCluster.exists(sessionId)) {
				JedisCluster.expire(sessionId, 0);
            }
        } catch (Exception e) {
        	LOG.error("Destroy session from redis error", e);
        }

	}

	@Override
	public boolean isJedisActive(){
		return true;
	}

	

}
